@@ -23,7 +23,7 @@ from wasabi import msg
 
 class TextRankSummarizerParameters(FormatterParameters):
     as_metadata: str = Field(None, description="""If defined generate the summary as a metadata of the input document,
-    if not replace the text of the inout document and remove all existing annotations and sentences.""")
+    if not replace the text of the input document.""")
     lang: str = Field("en",
                       description="Name of the 2-letter language of the documents")
     num_sentences: float = Field(0.25, description="""Number of sentences of the summary:<br/>
